# MPL BSIC Package

## Read Docs

Here is the link for the docs: [ReadTheDocs](https://mpl-bsic.readthedocs.io/)
1. Download the docs.pdf file (TODO)
2. Hosted docs (TODO)

## If the matplotlib fonts does not work

You have to install the .ttf and clean your matplotlib cache (full guide on the docs)

## TODOs

2) plot trade (as bloomberg with last price and stuff)